@@ -1,13 +1,37 @@
-#[doc = "Reader of register INTENSET"]
-pub type R = crate::R<u32, super::INTENSET>;
-#[doc = "Writer for register INTENSET"]
-pub type W = crate::W<u32, super::INTENSET>;
-#[doc = "Register INTENSET `reset()`'s with value 0"]
-impl crate::ResetValue for super::INTENSET {
-    type Type = u32;
+#[doc = "Register `INTENSET` reader"]
+pub struct R(crate::R<INTENSET_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<INTENSET_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl From<crate::R<INTENSET_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<INTENSET_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `INTENSET` writer"]
+pub struct W(crate::W<INTENSET_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<INTENSET_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<INTENSET_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<INTENSET_SPEC>) -> Self {
+        W(writer)
     }
 }
 #[doc = "Write '1' to enable interrupt for event READY\n\nValue on reset: 0"]
@@ -24,9 +48,12 @@ impl From<READY_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `READY`"]
-pub type READY_R = crate::R<bool, READY_A>;
+#[doc = "Field `READY` reader - Write '1' to enable interrupt for event READY"]
+pub struct READY_R(crate::FieldReader<bool, READY_A>);
 impl READY_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        READY_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> READY_A {
@@ -38,12 +65,19 @@ impl READY_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == READY_A::DISABLED
+        **self == READY_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == READY_A::ENABLED
+        **self == READY_A::ENABLED
+    }
+}
+impl core::ops::Deref for READY_R {
+    type Target = crate::FieldReader<bool, READY_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event READY\n\nValue on reset: 0"]
@@ -58,7 +92,7 @@ impl From<READY_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `READY`"]
+#[doc = "Field `READY` writer - Write '1' to enable interrupt for event READY"]
 pub struct READY_W<'a> {
     w: &'a mut W,
 }
@@ -66,9 +100,7 @@ impl<'a> READY_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: READY_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -88,7 +120,7 @@ impl<'a> READY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
@@ -106,9 +138,12 @@ impl From<ADDRESS_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `ADDRESS`"]
-pub type ADDRESS_R = crate::R<bool, ADDRESS_A>;
+#[doc = "Field `ADDRESS` reader - Write '1' to enable interrupt for event ADDRESS"]
+pub struct ADDRESS_R(crate::FieldReader<bool, ADDRESS_A>);
 impl ADDRESS_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        ADDRESS_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> ADDRESS_A {
@@ -120,12 +155,19 @@ impl ADDRESS_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == ADDRESS_A::DISABLED
+        **self == ADDRESS_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == ADDRESS_A::ENABLED
+        **self == ADDRESS_A::ENABLED
+    }
+}
+impl core::ops::Deref for ADDRESS_R {
+    type Target = crate::FieldReader<bool, ADDRESS_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event ADDRESS\n\nValue on reset: 0"]
@@ -140,7 +182,7 @@ impl From<ADDRESS_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `ADDRESS`"]
+#[doc = "Field `ADDRESS` writer - Write '1' to enable interrupt for event ADDRESS"]
 pub struct ADDRESS_W<'a> {
     w: &'a mut W,
 }
@@ -148,9 +190,7 @@ impl<'a> ADDRESS_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: ADDRESS_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -170,7 +210,7 @@ impl<'a> ADDRESS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
@@ -188,9 +228,12 @@ impl From<PAYLOAD_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `PAYLOAD`"]
-pub type PAYLOAD_R = crate::R<bool, PAYLOAD_A>;
+#[doc = "Field `PAYLOAD` reader - Write '1' to enable interrupt for event PAYLOAD"]
+pub struct PAYLOAD_R(crate::FieldReader<bool, PAYLOAD_A>);
 impl PAYLOAD_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        PAYLOAD_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> PAYLOAD_A {
@@ -202,12 +245,19 @@ impl PAYLOAD_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == PAYLOAD_A::DISABLED
+        **self == PAYLOAD_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == PAYLOAD_A::ENABLED
+        **self == PAYLOAD_A::ENABLED
+    }
+}
+impl core::ops::Deref for PAYLOAD_R {
+    type Target = crate::FieldReader<bool, PAYLOAD_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event PAYLOAD\n\nValue on reset: 0"]
@@ -222,7 +272,7 @@ impl From<PAYLOAD_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `PAYLOAD`"]
+#[doc = "Field `PAYLOAD` writer - Write '1' to enable interrupt for event PAYLOAD"]
 pub struct PAYLOAD_W<'a> {
     w: &'a mut W,
 }
@@ -230,9 +280,7 @@ impl<'a> PAYLOAD_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: PAYLOAD_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -252,7 +300,7 @@ impl<'a> PAYLOAD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | (((value as u32) & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
         self.w
     }
 }
@@ -270,9 +318,12 @@ impl From<END_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `END`"]
-pub type END_R = crate::R<bool, END_A>;
+#[doc = "Field `END` reader - Write '1' to enable interrupt for event END"]
+pub struct END_R(crate::FieldReader<bool, END_A>);
 impl END_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        END_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> END_A {
@@ -284,12 +335,19 @@ impl END_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == END_A::DISABLED
+        **self == END_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == END_A::ENABLED
+        **self == END_A::ENABLED
+    }
+}
+impl core::ops::Deref for END_R {
+    type Target = crate::FieldReader<bool, END_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event END\n\nValue on reset: 0"]
@@ -304,7 +362,7 @@ impl From<END_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `END`"]
+#[doc = "Field `END` writer - Write '1' to enable interrupt for event END"]
 pub struct END_W<'a> {
     w: &'a mut W,
 }
@@ -312,9 +370,7 @@ impl<'a> END_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: END_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -334,7 +390,7 @@ impl<'a> END_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | (((value as u32) & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
         self.w
     }
 }
@@ -352,9 +408,12 @@ impl From<DISABLED_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `DISABLED`"]
-pub type DISABLED_R = crate::R<bool, DISABLED_A>;
+#[doc = "Field `DISABLED` reader - Write '1' to enable interrupt for event DISABLED"]
+pub struct DISABLED_R(crate::FieldReader<bool, DISABLED_A>);
 impl DISABLED_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        DISABLED_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> DISABLED_A {
@@ -366,12 +425,19 @@ impl DISABLED_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == DISABLED_A::DISABLED
+        **self == DISABLED_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == DISABLED_A::ENABLED
+        **self == DISABLED_A::ENABLED
+    }
+}
+impl core::ops::Deref for DISABLED_R {
+    type Target = crate::FieldReader<bool, DISABLED_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event DISABLED\n\nValue on reset: 0"]
@@ -386,7 +452,7 @@ impl From<DISABLED_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `DISABLED`"]
+#[doc = "Field `DISABLED` writer - Write '1' to enable interrupt for event DISABLED"]
 pub struct DISABLED_W<'a> {
     w: &'a mut W,
 }
@@ -394,9 +460,7 @@ impl<'a> DISABLED_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: DISABLED_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -416,7 +480,7 @@ impl<'a> DISABLED_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | (((value as u32) & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
         self.w
     }
 }
@@ -434,9 +498,12 @@ impl From<DEVMATCH_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `DEVMATCH`"]
-pub type DEVMATCH_R = crate::R<bool, DEVMATCH_A>;
+#[doc = "Field `DEVMATCH` reader - Write '1' to enable interrupt for event DEVMATCH"]
+pub struct DEVMATCH_R(crate::FieldReader<bool, DEVMATCH_A>);
 impl DEVMATCH_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        DEVMATCH_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> DEVMATCH_A {
@@ -448,12 +515,19 @@ impl DEVMATCH_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == DEVMATCH_A::DISABLED
+        **self == DEVMATCH_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == DEVMATCH_A::ENABLED
+        **self == DEVMATCH_A::ENABLED
+    }
+}
+impl core::ops::Deref for DEVMATCH_R {
+    type Target = crate::FieldReader<bool, DEVMATCH_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event DEVMATCH\n\nValue on reset: 0"]
@@ -468,7 +542,7 @@ impl From<DEVMATCH_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `DEVMATCH`"]
+#[doc = "Field `DEVMATCH` writer - Write '1' to enable interrupt for event DEVMATCH"]
 pub struct DEVMATCH_W<'a> {
     w: &'a mut W,
 }
@@ -476,9 +550,7 @@ impl<'a> DEVMATCH_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: DEVMATCH_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -498,7 +570,7 @@ impl<'a> DEVMATCH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | (((value as u32) & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
         self.w
     }
 }
@@ -516,9 +588,12 @@ impl From<DEVMISS_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `DEVMISS`"]
-pub type DEVMISS_R = crate::R<bool, DEVMISS_A>;
+#[doc = "Field `DEVMISS` reader - Write '1' to enable interrupt for event DEVMISS"]
+pub struct DEVMISS_R(crate::FieldReader<bool, DEVMISS_A>);
 impl DEVMISS_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        DEVMISS_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> DEVMISS_A {
@@ -530,12 +605,19 @@ impl DEVMISS_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == DEVMISS_A::DISABLED
+        **self == DEVMISS_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == DEVMISS_A::ENABLED
+        **self == DEVMISS_A::ENABLED
+    }
+}
+impl core::ops::Deref for DEVMISS_R {
+    type Target = crate::FieldReader<bool, DEVMISS_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event DEVMISS\n\nValue on reset: 0"]
@@ -550,7 +632,7 @@ impl From<DEVMISS_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `DEVMISS`"]
+#[doc = "Field `DEVMISS` writer - Write '1' to enable interrupt for event DEVMISS"]
 pub struct DEVMISS_W<'a> {
     w: &'a mut W,
 }
@@ -558,9 +640,7 @@ impl<'a> DEVMISS_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: DEVMISS_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -580,7 +660,7 @@ impl<'a> DEVMISS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | (((value as u32) & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
         self.w
     }
 }
@@ -598,9 +678,12 @@ impl From<RSSIEND_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `RSSIEND`"]
-pub type RSSIEND_R = crate::R<bool, RSSIEND_A>;
+#[doc = "Field `RSSIEND` reader - Write '1' to enable interrupt for event RSSIEND"]
+pub struct RSSIEND_R(crate::FieldReader<bool, RSSIEND_A>);
 impl RSSIEND_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        RSSIEND_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RSSIEND_A {
@@ -612,12 +695,19 @@ impl RSSIEND_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == RSSIEND_A::DISABLED
+        **self == RSSIEND_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == RSSIEND_A::ENABLED
+        **self == RSSIEND_A::ENABLED
+    }
+}
+impl core::ops::Deref for RSSIEND_R {
+    type Target = crate::FieldReader<bool, RSSIEND_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event RSSIEND\n\nValue on reset: 0"]
@@ -632,7 +722,7 @@ impl From<RSSIEND_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `RSSIEND`"]
+#[doc = "Field `RSSIEND` writer - Write '1' to enable interrupt for event RSSIEND"]
 pub struct RSSIEND_W<'a> {
     w: &'a mut W,
 }
@@ -640,9 +730,7 @@ impl<'a> RSSIEND_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: RSSIEND_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -662,7 +750,7 @@ impl<'a> RSSIEND_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
@@ -680,9 +768,12 @@ impl From<BCMATCH_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `BCMATCH`"]
-pub type BCMATCH_R = crate::R<bool, BCMATCH_A>;
+#[doc = "Field `BCMATCH` reader - Write '1' to enable interrupt for event BCMATCH"]
+pub struct BCMATCH_R(crate::FieldReader<bool, BCMATCH_A>);
 impl BCMATCH_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        BCMATCH_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> BCMATCH_A {
@@ -694,12 +785,19 @@ impl BCMATCH_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == BCMATCH_A::DISABLED
+        **self == BCMATCH_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == BCMATCH_A::ENABLED
+        **self == BCMATCH_A::ENABLED
+    }
+}
+impl core::ops::Deref for BCMATCH_R {
+    type Target = crate::FieldReader<bool, BCMATCH_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event BCMATCH\n\nValue on reset: 0"]
@@ -714,7 +812,7 @@ impl From<BCMATCH_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `BCMATCH`"]
+#[doc = "Field `BCMATCH` writer - Write '1' to enable interrupt for event BCMATCH"]
 pub struct BCMATCH_W<'a> {
     w: &'a mut W,
 }
@@ -722,9 +820,7 @@ impl<'a> BCMATCH_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: BCMATCH_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -744,7 +840,7 @@ impl<'a> BCMATCH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | (((value as u32) & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
         self.w
     }
 }
@@ -762,9 +858,12 @@ impl From<CRCOK_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `CRCOK`"]
-pub type CRCOK_R = crate::R<bool, CRCOK_A>;
+#[doc = "Field `CRCOK` reader - Write '1' to enable interrupt for event CRCOK"]
+pub struct CRCOK_R(crate::FieldReader<bool, CRCOK_A>);
 impl CRCOK_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        CRCOK_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> CRCOK_A {
@@ -776,12 +875,19 @@ impl CRCOK_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == CRCOK_A::DISABLED
+        **self == CRCOK_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == CRCOK_A::ENABLED
+        **self == CRCOK_A::ENABLED
+    }
+}
+impl core::ops::Deref for CRCOK_R {
+    type Target = crate::FieldReader<bool, CRCOK_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event CRCOK\n\nValue on reset: 0"]
@@ -796,7 +902,7 @@ impl From<CRCOK_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `CRCOK`"]
+#[doc = "Field `CRCOK` writer - Write '1' to enable interrupt for event CRCOK"]
 pub struct CRCOK_W<'a> {
     w: &'a mut W,
 }
@@ -804,9 +910,7 @@ impl<'a> CRCOK_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: CRCOK_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -826,7 +930,7 @@ impl<'a> CRCOK_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | (((value as u32) & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
         self.w
     }
 }
@@ -844,9 +948,12 @@ impl From<CRCERROR_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `CRCERROR`"]
-pub type CRCERROR_R = crate::R<bool, CRCERROR_A>;
+#[doc = "Field `CRCERROR` reader - Write '1' to enable interrupt for event CRCERROR"]
+pub struct CRCERROR_R(crate::FieldReader<bool, CRCERROR_A>);
 impl CRCERROR_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        CRCERROR_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> CRCERROR_A {
@@ -858,12 +965,19 @@ impl CRCERROR_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == CRCERROR_A::DISABLED
+        **self == CRCERROR_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == CRCERROR_A::ENABLED
+        **self == CRCERROR_A::ENABLED
+    }
+}
+impl core::ops::Deref for CRCERROR_R {
+    type Target = crate::FieldReader<bool, CRCERROR_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event CRCERROR\n\nValue on reset: 0"]
@@ -878,7 +992,7 @@ impl From<CRCERROR_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `CRCERROR`"]
+#[doc = "Field `CRCERROR` writer - Write '1' to enable interrupt for event CRCERROR"]
 pub struct CRCERROR_W<'a> {
     w: &'a mut W,
 }
@@ -886,9 +1000,7 @@ impl<'a> CRCERROR_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: CRCERROR_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -908,7 +1020,7 @@ impl<'a> CRCERROR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | (((value as u32) & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
         self.w
     }
 }
@@ -926,9 +1038,12 @@ impl From<TXREADY_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `TXREADY`"]
-pub type TXREADY_R = crate::R<bool, TXREADY_A>;
+#[doc = "Field `TXREADY` reader - Write '1' to enable interrupt for event TXREADY"]
+pub struct TXREADY_R(crate::FieldReader<bool, TXREADY_A>);
 impl TXREADY_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        TXREADY_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TXREADY_A {
@@ -940,12 +1055,19 @@ impl TXREADY_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == TXREADY_A::DISABLED
+        **self == TXREADY_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == TXREADY_A::ENABLED
+        **self == TXREADY_A::ENABLED
+    }
+}
+impl core::ops::Deref for TXREADY_R {
+    type Target = crate::FieldReader<bool, TXREADY_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event TXREADY\n\nValue on reset: 0"]
@@ -960,7 +1082,7 @@ impl From<TXREADY_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `TXREADY`"]
+#[doc = "Field `TXREADY` writer - Write '1' to enable interrupt for event TXREADY"]
 pub struct TXREADY_W<'a> {
     w: &'a mut W,
 }
@@ -968,9 +1090,7 @@ impl<'a> TXREADY_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: TXREADY_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -990,7 +1110,7 @@ impl<'a> TXREADY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | (((value as u32) & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
         self.w
     }
 }
@@ -1008,9 +1128,12 @@ impl From<RXREADY_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `RXREADY`"]
-pub type RXREADY_R = crate::R<bool, RXREADY_A>;
+#[doc = "Field `RXREADY` reader - Write '1' to enable interrupt for event RXREADY"]
+pub struct RXREADY_R(crate::FieldReader<bool, RXREADY_A>);
 impl RXREADY_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        RXREADY_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RXREADY_A {
@@ -1022,12 +1145,19 @@ impl RXREADY_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == RXREADY_A::DISABLED
+        **self == RXREADY_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == RXREADY_A::ENABLED
+        **self == RXREADY_A::ENABLED
+    }
+}
+impl core::ops::Deref for RXREADY_R {
+    type Target = crate::FieldReader<bool, RXREADY_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event RXREADY\n\nValue on reset: 0"]
@@ -1042,7 +1172,7 @@ impl From<RXREADY_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `RXREADY`"]
+#[doc = "Field `RXREADY` writer - Write '1' to enable interrupt for event RXREADY"]
 pub struct RXREADY_W<'a> {
     w: &'a mut W,
 }
@@ -1050,9 +1180,7 @@ impl<'a> RXREADY_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: RXREADY_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -1072,7 +1200,7 @@ impl<'a> RXREADY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | (((value as u32) & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
         self.w
     }
 }
@@ -1090,9 +1218,12 @@ impl From<PHYEND_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `PHYEND`"]
-pub type PHYEND_R = crate::R<bool, PHYEND_A>;
+#[doc = "Field `PHYEND` reader - Write '1' to enable interrupt for event PHYEND"]
+pub struct PHYEND_R(crate::FieldReader<bool, PHYEND_A>);
 impl PHYEND_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        PHYEND_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> PHYEND_A {
@@ -1104,12 +1235,19 @@ impl PHYEND_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == PHYEND_A::DISABLED
+        **self == PHYEND_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == PHYEND_A::ENABLED
+        **self == PHYEND_A::ENABLED
+    }
+}
+impl core::ops::Deref for PHYEND_R {
+    type Target = crate::FieldReader<bool, PHYEND_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event PHYEND\n\nValue on reset: 0"]
@@ -1124,7 +1262,7 @@ impl From<PHYEND_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `PHYEND`"]
+#[doc = "Field `PHYEND` writer - Write '1' to enable interrupt for event PHYEND"]
 pub struct PHYEND_W<'a> {
     w: &'a mut W,
 }
@@ -1132,9 +1270,7 @@ impl<'a> PHYEND_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: PHYEND_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -1154,7 +1290,7 @@ impl<'a> PHYEND_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | (((value as u32) & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
         self.w
     }
 }
@@ -1301,4 +1437,30 @@ impl W {
     pub fn phyend(&mut self) -> PHYEND_W {
         PHYEND_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Enable interrupt\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [intenset](index.html) module"]
+pub struct INTENSET_SPEC;
+impl crate::RegisterSpec for INTENSET_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [intenset::R](R) reader structure"]
+impl crate::Readable for INTENSET_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [intenset::W](W) writer structure"]
+impl crate::Writable for INTENSET_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets INTENSET to value 0"]
+impl crate::Resettable for INTENSET_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0
+    }
 }
